/*********************************************************************
*               (c) SEGGER Microcontroller GmbH & Co. KG             *
*                        The Embedded Experts                        *
*                           www.segger.com                           *
**********************************************************************
*/

#define U8  unsigned char
#define U16 unsigned short
#define U32 unsigned long

#define I8  signed char
#define I16 signed short
#define I32 signed long

#define ONCHIP     1           // On-chip Flash Memory

#define MAX_NUM_SECTORS (512)      // Max Number of Sector Items
#define MAX_SIZE_PAGE   (0x10000)  // Max Page Size for Programming
#define ALGO_VERSION    (0x0101)   // Algo version, must not be modified.


struct SECTOR_INFO  {
  U32 SectorSize;       // Sector Size in Bytes
  U32 SectorStartAddr;  // Address of Sector
};

struct FlashDevice  {
   U16 AlgoVer;       // Algo version number
   U8  Name[128];     // Device Name and Description
   U16 Type;          // Device Type: ONCHIP, EXT8BIT, EXT16BIT, ...
   U32 BaseAddr;      // Default Device Start Address
   U32 TotalSize;     // Total Size of Device
   U32 PageSize;      // Programming Page Size
   U32 Reserved;      // Reserved for future Extension
   U8  ErasedVal;     // Content of Erased Memory
   U32 TimeoutProg;   // Time Out of Program Page Function
   U32 TimeoutErase;  // Time Out of Erase Sector Function
   struct SECTOR_INFO SectorInfo[MAX_NUM_SECTORS];
};

//
// Flash module functions
//
extern int Init        (U32 Addr, U32 Freq, U32 Func);
extern int UnInit      (U32 Func);
extern int BlankCheck  (U32 Addr, U32 Size, U32 Pat);
extern int EraseChip   (void);
extern int EraseSector (U32 Addr);
extern int ProgramPage (U32 Addr, U32 Size, U8 *pSrcBuff);
extern U32 Verify      (U32 Addr, U32 Size, U8 *pSrcBuff);
